aboutsummaryrefslogtreecommitdiff
path: root/sim/common/sim-events.c
diff options
context:
space:
mode:
authorChris Demetriou <cgd@google.com>2002-02-10 23:11:37 +0000
committerChris Demetriou <cgd@google.com>2002-02-10 23:11:37 +0000
commit6439295f61b598227751815bf233fd9aa07fa37b (patch)
treece6ffe8d8efa579c009344554de6c36e6a79cce2 /sim/common/sim-events.c
parente55c0b759bf5dc779457f9a986a446ee2b123208 (diff)
downloadfsf-binutils-gdb-6439295f61b598227751815bf233fd9aa07fa37b.zip
fsf-binutils-gdb-6439295f61b598227751815bf233fd9aa07fa37b.tar.gz
fsf-binutils-gdb-6439295f61b598227751815bf233fd9aa07fa37b.tar.bz2
2002-02-10 Chris Demetriou <cgd@broadcom.com>
* callback.c: Fix some spelling errors. * hw-device.h: Likewise. * hw-tree.c: Likewise. * sim-abort.c: Likewise. * sim-alu.h: Likewise. * sim-core.h: Likewise. * sim-events.c: Likewise. * sim-events.h: Likewise. * sim-fpu.h: Likewise. * sim-profile.h: Likewise. * sim-utils.c: Likewise.
Diffstat (limited to 'sim/common/sim-events.c')
-rw-r--r--sim/common/sim-events.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sim/common/sim-events.c b/sim/common/sim-events.c
index 1866b2d..22531e3 100644
--- a/sim/common/sim-events.c
+++ b/sim/common/sim-events.c
@@ -37,7 +37,7 @@
#include <stdlib.h>
#endif
-#include <signal.h> /* For SIGPROCMASK et.al. */
+#include <signal.h> /* For SIGPROCMASK et al. */
typedef enum {
watch_invalid,
@@ -112,7 +112,7 @@ struct _sim_event {
variables.
TIME_OF_EVENT: this holds the time at which the next event is ment
- to occure. If no next event it will hold the time of the last
+ to occur. If no next event it will hold the time of the last
event.
TIME_FROM_EVENT: The current distance from TIME_OF_EVENT. A value
@@ -447,7 +447,7 @@ insert_sim_event (SIM_DESC sd,
if (delta < 0)
sim_io_error (sd, "what is past is past!\n");
/* compute when the event should occure */
time_of_event = sim_events_time (sd) + delta;
/* find the queue insertion point - things are time ordered */
@@ -447,7 +447,7 @@ insert_sim_event (SIM_DESC sd,
if (delta < 0)
sim_io_error (sd, "what is past is past!\n");
- /* compute when the event should occure */
+ /* compute when the event should occur */
time_of_event = sim_events_time (sd) + delta;
/* find the queue insertion point - things are time ordered */